KindData

Enum KindData 

#[non_exhaustive]
pub enum KindData {
Show 23 variants Document(Document), Paragraph(Paragraph), Heading(Heading), ThematicBreak(ThematicBreak), CodeBlock(CodeBlock), Blockquote(Blockquote), List(List), ListItem(ListItem), HtmlBlock(HtmlBlock), Text(Text), CodeSpan(CodeSpan), Emphasis(Emphasis), Link(Link), Image(Image), RawHtml(RawHtml), LinkReferenceDefinition(LinkReferenceDefinition), Table(Table), TableHeader(TableHeader), TableBody(TableBody), TableRow(TableRow), TableCell(TableCell), Strikethrough(Strikethrough), Extension(Box<dyn ExtensionData>),
}
Represents the data of a node in the document. This is an enum that can hold different types of node data.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Document(Document)



Paragraph(Paragraph)



Heading(Heading)



ThematicBreak(ThematicBreak)



CodeBlock(CodeBlock)



Blockquote(Blockquote)



List(List)



ListItem(ListItem)



HtmlBlock(HtmlBlock)



Text(Text)



CodeSpan(CodeSpan)



Emphasis(Emphasis)



Image(Image)



RawHtml(RawHtml)



LinkReferenceDefinition(LinkReferenceDefinition)



Table(Table)



TableHeader(TableHeader)



TableBody(TableBody)



TableRow(TableRow)



TableCell(TableCell)



Strikethrough(Strikethrough)



Extension(Box<dyn ExtensionData>)

Implementations

Source

impl KindData

pub fn typ(&self) -> NodeType

Returns the type of the node.

pub fn kind_name(&self) -> &'static str

Returns the kind name of the node.

pub fn pretty_print( &self, w: &mut dyn Write, source: &str, level: usize, ) -> Result

Pretty prints the node data.