pub trait ExtensionData:
Debug
+ PrettyPrint
+ NodeKind
+ Any {
// Required method
fn as_any(&self) -> &dyn Any;
}Expand description
A composite trait for nodes will be added from outside of this library.
pub trait ExtensionData:
Debug
+ PrettyPrint
+ NodeKind
+ Any {
// Required method
fn as_any(&self) -> &dyn Any;
}A composite trait for nodes will be added from outside of this library.