Context

Struct Context 

pub struct Context { /* private fields */ }
A context for parsing operations.

Implementations

Source

impl Context

pub fn new() -> Self

Creates a new Context with default options.

pub fn with_options(options: ContextOptions) -> Self

Creates a new Context with the given options.

Adds a link reference definition to the context.

Gets a link reference definition by label.

Gets all link reference definitions.

pub fn last_delimiter(&self) -> Option<ParseStackElemRef>

Gets the last opened delimiter reference.

pub fn insert<T: AnyValueSpec>(&mut self, key: ContextKey<T>, value: T::Item)

Inserts a value into the context.

pub fn get<T: AnyValueSpec>(&self, key: ContextKey<T>) -> Option<&T::Item>

Gets a reference to a value from the context.

pub fn get_mut<T: AnyValueSpec>( &mut self, key: ContextKey<T>, ) -> Option<&mut T::Item>

Gets a mutable reference to a value from the context.

pub fn remove<T: AnyValueSpec>(&mut self, key: ContextKey<T>) -> Option<T::Item>

Removes a value from the context.

pub fn ids(&self) -> &NodeIds

Returns an ids.

pub fn ids_mut(&mut self) -> &mut NodeIds

Returns a mutable ids.

pub fn last_opened_block(&self) -> Option<NodeRef>

Returns the last opened block node reference.

pub fn block_offset(&self) -> Option<usize>

Returns a first non-space character position on current line. This value is valid only for BlockParser::open. This returns None if current line is blank.

pub fn block_indent(&self) -> Option<usize>

Returns an indent width on current line. This value is valid only for BlockParser::open. This returns None if current line is blank.

Returns whether the parser is currently in a link label.