Options

Struct Options 

pub struct Options {
    pub attributes: bool,
    pub auto_heading_ids: bool,
    pub without_default_parsers: bool,
    pub arena: ArenaOptions,
    pub escaped_space: bool,
    pub id_generator: Option<Rc<dyn GenerateNodeId>>,
}
Options for the parser.

Fields

attributes: bool

Enables attributes.

auto_heading_ids: bool

Enables auto heading ids.

without_default_parsers: bool

If true, default parsers will not be added automatically. However, if you do not include parsers for IndentedCodeBlock and Paragraph, the behavior is undefined. If you omit them, you must implement and add:

  • a BlockParser that handles indented lines
  • a BlockParser that handles non-indented lines
arena: ArenaOptions

Options for the AST arena.

escaped_space: bool

If true, a ’' escaped half-space(0x20) will not trigger parsers.

id_generator: Option<Rc<dyn GenerateNodeId>>

A custom node ID generator.