Value

Enum Value 

#[non_exhaustive]
pub enum Value { Index(Index), String(String), }
An enum represents a string value that can be either an Index or a String. Value does not handle padding. Value is used for representing values that can be represented by a single line, such as link destinations.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Index(Index)

An Index variant holds a reference to indicies in the source.



String(String)

A String variant holds a string value.

Implementations

Source

impl Value

pub fn bytes<'a>(&'a self, source: &'a str) -> &'a [u8]

Returns byte slice value.

pub fn str<'a>(&'a self, source: &'a str) -> &'a str

Returns str value.

pub fn is_empty(&self) -> bool

Returns true if the value is empty, otherwise false.

pub fn len(&self) -> usize

Returns the length of the value.