Index

Struct Index 

pub struct Index { /* private fields */ }
An Index struct holds information about source positions.

Implementations

Source

impl Index

pub fn new(start: usize, stop: usize) -> Self

Create a new Index with start and stop.

pub fn start(&self) -> usize

A Start position of the index.

pub fn stop(&self) -> usize

A Stop position of the index.

pub fn bytes<'a>(&self, source: &'a str) -> &'a [u8]

Returns the bytes of the index from the source.

pub fn str<'a>(&self, source: &'a str) -> &'a str

Returns the str of the index from the source.

Safety

This method does not check the validity of UTF-8 boundaries.

pub fn is_empty(&self) -> bool

Returns true if the index is empty, otherwise false.

pub fn with_start(&self, v: usize) -> Index

Returns a new Index with same value except stop.

pub fn with_stop(&self, v: usize) -> Index

Returns a new Index with same value except stop.

pub fn len(&self) -> usize

Returns the length of the index.