Built-in parsers.
Structs
- AtxHeading
Parser BlockParserfor ATX headings.- Auto
Link Parser - InlineParser that parses auto links.
- Blockquote
Parser BlockParserfor blockquotes.- Chained
Parser Extension - A parser extension that chains two extensions together.
- Code
Span Parser InlineParserfor inline codes.- Context
- A context for parsing operations.
- Context
Options - Options for configuring the
Context. - Delimiter
- Represents a delimiter. A Delimiter is a parse stack element that has same opener and closer characters. CommonMark emphasis syntax uses delimiters.
- Delimiter
Processor - Callbacks for processing delimiters.
- Emphasis
Parser InlineParserfor emphasis.- Empty
Parser Extension - An empty parser extension that does nothing.
- Fenced
Code Block Parser BlockParserfor fenced code blocks.- GfmOptions
- Options for GitHub Flavored Markdown (GFM).
- Html
Block Parser BlockParserfor html blocks.- Indented
Code Block Parser BlockParserfor indented code blocks.- Link
Parser InlineParserfor links.- Link
Reference Paragraph Transformer ParagraphTransformerthat extracts link reference definitions from paragraphs.- Linkify
Options - Options for GFM auto links.
- Linkify
Parser InlineParserthat linkifies URLs and email addresses.- List
Item Parser BlockParserfor list items.- List
Parser BlockParserfor lists.- NoParser
Options - A default implementation of ParserOptions that does nothing.
- NodeIds
- A collection of node IDs.
- Options
- Options for the parser.
- Paragraph
Parser BlockParserfor paragraphs.- Parse
Stack Elem Ref - Represents a reference to a element in the parse stack.
- Parser
- A parser for parsing text into an AST.
- Parser
Constructor Options - Options for constructing a parser.
- Parser
Extension Fn - A parser extension defined by a closure.
- RawHtml
Parser InlineParserfor inline raw HTML.- Setext
Heading Parser BlockParserfor Setext headings.- State
- Represents parser’s state.
- Strikethrough
Parser InlineParserfor strikethrough text.- Table
AstTransformer AstTransformerthat transforms escaped pipe cells in tables.- Table
Paragraph Transformer ParagraphTransformerthat transforms table paragraphs into table nodes.- Task
List Item Paragraph Transformer ParagraphTransformerthat transforms list items into task list items.- Thematic
Break Parser BlockParserfor thematic breaks.
Enums
- AnyAst
Transformer - An enum of all AST transformers.
- AnyBlock
Parser - An enum of all block parsers.
- AnyInline
Parser - An enum of all inline parsers.
- AnyParagraph
Transformer - An enum of all Paragraph transformers.
Constants
- NO_
EXTENSIONS - An empty parser extension that does nothing.
- PRIORITY_
ATX_ HEADING - Priority for ATX heading parser.
- PRIORITY_
AUTO_ LINK - Priority for auto link parser.
- PRIORITY_
BLOCKQUOTE - Priority for blockquote parser.
- PRIORITY_
CODE_ SPAN - Priority for code span parser.
- PRIORITY_
EMPHASIS - Priority for emphasis parser.
- PRIORITY_
FENCED_ CODE_ BLOCK - Priority for fenced code block parser.
- PRIORITY_
HTML_ BLOCK - Priority for HTML block parser.
- PRIORITY_
INDENTED_ CODE_ BLOCK - Priority for indented code block parser.
- PRIORITY_
LINK - Priority for link parser.
- PRIORITY_
LIST - Priority for list parser.
- PRIORITY_
LIST_ ITEM - Priority for list item parser.
- PRIORITY_
PARAGRAPH - Priority for paragraph parser.
- PRIORITY_
RAW_ HTML - Priority for raw HTML parser.
- PRIORITY_
SETTEXT_ HEADING - Priority for setext heading parser.
- PRIORITY_
THEMATIC_ BREAK - Priority for thematic break parser.
Traits
- AstTransformer
- A trait that transforms AST nodes.
- Block
Parser - A trait that parses a block level element like Paragraph, List, Blockquote etc.
- Generate
Node Id - A trait for generating unique node IDs.
- Inline
Parser - A trait that parses an inline level element like CodeSpan, Link etc.
- Paragraph
Transformer - A trait that transforms Paragraph nodes.
- Parser
Constructor - A trait for constructing parsers with varying arguments.
- Parser
Extension - A trait for extending the parser with custom behavior.
- Parser
Options - A trait for parser options. Each parser can define its own options by implementing this trait.
Functions
- gfm
- Returns a
ParserExtensionthat adds GitHub Flavored Markdown (GFM) - gfm_
linkify - Returns a
ParserExtensionthat adds GitHub Flavored Markdown (GFM) linkify support. - gfm_
strikethrough - Returns a
ParserExtensionthat adds GitHub Flavored Markdown (GFM) strikethrough support. - gfm_
table - Returns a
ParserExtensionthat adds GitHub Flavored Markdown (GFM) table support. - gfm_
task_ list_ item - Returns a
ParserExtensionthat adds GitHub Flavored Markdown (GFM) task list item support. - parse_
attributes - Parses attributes from the reader. If attributes are found, returns Some(Attributes). Otherwise, returns None and resets the reader position
- parse_
delimiter - Parse a delimiter run in the reader.
If a delimiter run is found, it is added to the context’s delimiter list,
and the reader is advanced past the delimiter run.
Returns a
NodeRefto the text node representing the delimiter run. - process_
delimiters - Processes the delimiter list in the context. Processing will be stop when reaching the bottom.