pub struct Options {
pub attributes: bool,
pub auto_heading_ids: bool,
pub without_default_parsers: bool,
pub arena: ArenaOptions,
pub escaped_space: bool,
pub id_generator: Option<Rc<dyn GenerateNodeId>>,
}Expand description
Options for the parser.
Fields
attributes: boolEnables attributes.
auto_heading_ids: boolEnables auto heading ids.
without_default_parsers: boolIf true, default parsers will not be added automatically. However, if you do not include parsers for IndentedCodeBlock and Paragraph, the behavior is undefined. If you omit them, you must implement and add:
- a BlockParser that handles indented lines
- a BlockParser that handles non-indented lines
arena: ArenaOptionsOptions for the AST arena.
escaped_space: boolIf true, a ’' escaped half-space(0x20) will not trigger parsers.
id_generator: Option<Rc<dyn GenerateNodeId>>A custom node ID generator.