Text related structures and traits.
Structs
- Basic
Reader Readerimplementation for byte slices.- Block
Reader Readerimplementation for given blocks.- Index
- An Index struct holds information about source positions.
- Segment
- A Segment struct repsents a segment of CommonMark text.
In addition to
Index, Segment has padding and force_newline fields.
Enums
- Value
- An enum represents a string value that can be either an
Indexor aString.Valuedoes not handle padding and new lines.
Constants
- EOS
- Indicates the end of string.
Traits
- Reader
- A Reader trait represents a reader that can read and peek bytes.
Functions
- block_
to_ bytes - Converts a
Blockto a bytes. - block_
to_ str - Converts a
Blockto a str. - block_
to_ value - Converts a
Blockto a Value.
Type Aliases
- Block
- Special collection of segments. Each segment represents a one line. Each segment does not contain multiple lines.