pub struct Index { /* private fields */ }Expand description
An Index struct holds information about source positions.
Implementations
Sourceimpl Index
impl Index
Sourcepub fn bytes<'a>(&self, source: &'a str) -> &'a [u8] ⓘ
pub fn bytes<'a>(&self, source: &'a str) -> &'a [u8] ⓘ
Returns the bytes of the index from the source.
Sourcepub fn str<'a>(&self, source: &'a str) -> &'a str
pub fn str<'a>(&self, source: &'a str) -> &'a str
Returns the str of the index from the source.
Safety
This method does not check the validity of UTF-8 boundaries.
Sourcepub fn with_start(&self, v: usize) -> Index
pub fn with_start(&self, v: usize) -> Index
Returns a new Index with same value except stop.